@@ -32,7 +32,8 @@ def cal_DELAY(refFile=None, testFile=None):
         mydll = ctypes.windll.LoadLibrary(sys.prefix + '/agcDelay.dll')
     if cur_paltform == 'macOS':
         mydll = CDLL(sys.prefix + '/agcDelay.dylib')
-
+    if cur_paltform == 'Linux':
+        mydll = CDLL(sys.prefix + '/agcDelay.so')
     mydll.delay_estimation_15s.argtypes = [POINTER(emxArray_real_T),POINTER(emxArray_real_T),c_double,POINTER(c_double),POINTER(c_double)]
     delay,err = c_double(0.0),c_double(0.0)
     mydll.delay_estimation_15s(byref(refstruct),byref(teststruct),c_double(refsamplerate),byref(delay),byref(err))
