@@ -12,8 +12,8 @@ from commFunction import emxArray_real_T,get_data_of_ctypes_
 def cal_snr_music(refFile=None, testFile=None):
     """
     """
-    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile,True)
-    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile,True)
+    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile,False)
+    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile,False)
     if refsamplerate != testsamplerate:
         raise TypeError('Different format of ref and test files!')
 
